#!/usr/local/bin/perl 
# -*- Perl -*- Wed Nov 12 08:59:18 CST 2003 
###############################################################################
# Written by Tim Skirvin <tskirvin@killfile.org> 
# Copyright 2000-2003, Tim Skirvin.  Redistribution terms are below.
###############################################################################
our $VERSION = 1.5;

=head1 NAME

counter.pl - a really simple web counter

=cut

###############################################################################
### PREREQUISITIES ##########################################################
###############################################################################

# use lib '/home/tskirvin/dev/counter';
use File::CounterFile::Date;
use strict;
use warnings;
use Getopt::Std;

###############################################################################
### USER VARIABLES ############################################################
###############################################################################

use vars qw( $DEFAULT_DIR );
$ENV{'HOST'} ||= "";
if ($ENV{'HOST'} eq 'bremen') {
  $DEFAULT_DIR = "/home/webserver/counterlog2/";
} else {
  $DEFAULT_DIR = "/home/webserver/counterlog/";
}


###############################################################################
### Documentatation ###########################################################
###############################################################################

=head1 SYNOPSIS

  counter.pl [-p page] [-n]

=head1 DESCRIPTION

This is just a simple web counter.  You invoke it by running it; it
figures out what you're invoking it from from the environment variable
C<SCRIPT_NAME> and goes from there.  If you don't want to use this
environment variable, then you can specify the page you want to look at
with the C<-p> flag instead.  

If you want to not print anything, and just return the appropriate value,
use the C<-q> flag.  If you only want to print the number of accesses, and
not the "xx accesses since DATE" it, use C<-c>.  Finally, if you just want
the current value, and not an update, use the C<-n> flag.

=head1 NOTES

Requires File::CounterFile::Date, and anything that it requires.  The
directory that you want to use to write to must exist and be writable by
the running user (probably the web server user), or you will get errors.

=head1 TODO

Some more of this stuff should be generic, like the output of the date
string and the parts of the URL that are trimmed.

=head1 AUTHOR

Tim Skirvin (tskirvin@ks.uiuc.edu) 

=head1 VERSION 

v1.0 - Thu Apr 20 09:50:08 CDT 2000 - Documented it and made it go.  
v1.5 - Wed Nov 12 09:01:18 CST 2003 - Wrote my own File::CounterFile::Date, 
	and this uses it.  Now keeps track of the created time.

=head1 COPYRIGHT

Copyright 2000-2003 by Tim Skirvin (tskirvin@killfile.org)  This code may
be redistributed under the same terms as Perl itself.

=cut

### main() ##################################################################
print "Content-type: text/html\n\n";
# use CGI; print CGI->header, "\n";
use vars qw( $opt_p $opt_n $opt_q $opt_c );	# Get the command line options
getopts('p:nqc');

my $page = $opt_p ? $opt_p : $ENV{'DOCUMENT_URI'} || "";
exit(0) unless $page;

# warn "Page: $page\n";

$page =~ s%~%HOME/%g;		# Replace ~'s with HOME for the dir structure
$page =~ s%http:/+(www(-s)?.ks.uiuc.edu|www|ruse.ks.uiuc.edu|ruse)?/?%%g;	
$page =~ s%/+%/%g;

$page =~ m%^(.*)/([^/]*)$%;	# Create the directory structure	
my $directory = $1 || "";
my $topdir = $DEFAULT_DIR;
foreach (split ('/', $directory) ) {
  $topdir = join ('/', $topdir, $_);  $topdir =~ s%/+%/%g;
  unless (-d $topdir) {
    # warn "mkdir $topdir\n";
    mkdir $topdir, 0777 
  }
}

$page =~ s%/$%%g;	# Trim trailing '/' characters.

my $counter = File::CounterFile::Date->new( join('', $DEFAULT_DIR, $page));

$counter->lock;
$counter++ unless $opt_n;	# Increment the counter
my $value = $counter->value || 0;   my $date = $counter->created || time;
$counter->unlock;

unless ($opt_q) { 
  # my $formdate = scalar localtime $date;	# Should be more definable
  my @months = qw( Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec );
  my $formdate = sprintf("%02d %3s %4d", 
                (localtime($date))[3], 
                $months[(localtime($date))[4]],
                (localtime($date))[5] + 1900 );
  print $opt_c ? "$value\n" : "$value accesses since $formdate\n";
}
exit  $value || 0;		# Return the value
